IRBexpr

Struct IRBexpr 

pub struct IRBexpr<A>(/* private fields */);
Represents boolean expressions over some arithmetic expression type A.

Implementations

Source

impl<T> IRBexpr<T>

pub fn map<O>(self, f: &mut impl FnMut(T) -> O) -> IRBexpr<O>

Transforms the inner expression into a different type.

pub fn map_into<O>(&self, f: &mut impl FnMut(&T) -> O) -> IRBexpr<O>

Transforms the inner expression into a different type without moving the struct.

pub fn try_map<O, E>( self, f: &mut impl FnMut(T) -> Result<O, E>, ) -> Result<IRBexpr<O>, E>

Transforms the inner expression into a different type, potentially failing.

pub fn map_inplace(&mut self, f: &mut impl FnMut(&mut T))

Transforms the inner expression in place instead of returning a new expression.

pub fn try_map_inplace<E>( &mut self, f: &mut impl FnMut(&mut T) -> Result<(), E>, ) -> Result<(), E>

Tries to transform the inner expression in place instead of returning a new expression.

pub fn det(expr: T) -> Self

Creates a expression that indicates the backend must prove deterministic.

pub fn eq(lhs: T, rhs: T) -> Self

Creates a constraint with CmpOp::Eq between two expressions.

pub fn lt(lhs: T, rhs: T) -> Self

Creates a constraint with CmpOp::Lt between two expressions.

pub fn le(lhs: T, rhs: T) -> Self

Creates a constraint with CmpOp::Le between two expressions.

pub fn gt(lhs: T, rhs: T) -> Self

Creates a constraint with CmpOp::Gt between two expressions.

pub fn ge(lhs: T, rhs: T) -> Self

Creates a constraint with CmpOp::Ge between two expressions.

pub fn implies(self, rhs: Self) -> Self

Creates an implication expression.

pub fn iff(self, rhs: Self) -> Self

Creates a double implication expression.

pub fn and(self, rhs: Self) -> Self

Creates a logical AND.

pub fn and_many(exprs: impl IntoIterator<Item = Self>) -> Self

Creates a logical AND from a sequence of expressions.

pub fn or(self, rhs: Self) -> Self

Creates a logical OR.

pub fn or_many(exprs: impl IntoIterator<Item = Self>) -> Self

Creates a logical OR from a sequence of expressions.

pub fn with<O>(self, other: O) -> IRBexpr<(O, T)>
where O: Clone,

Maps the statement’s inner type to a tuple with the passed value.

pub fn with_fn<O>(self, other: impl Fn() -> O) -> IRBexpr<(O, T)>

Maps the statement’s inner type to a tuple with the result of the closure.