IRGroup

Struct IRGroup 

pub struct IRGroup<E> { /* private fields */ }
Body of a group.

Implementations

Source

impl<E> IRGroup<E>

pub fn new(name: String, id: usize) -> Self

Creates a new empty group.

pub fn with_input_count(self, input_count: usize) -> Self

Updates the input count of the group.

pub fn with_output_count(self, output_count: usize) -> Self

Updates the output count of the group.

pub fn with_key(self, key: Option<GroupKey>) -> Self

Updates the group key.

pub fn no_key(self) -> Self

Removes the group key.

pub fn with_gates(self, gates: impl IntoIterator<Item = IRStmt<E>>) -> Self

Updates the IR of the PLONK gates.

pub fn with_copy_constraints( self, constraints: impl IntoIterator<Item = IRStmt<E>>, ) -> Self

Updates the IR of the copy constraints.

pub fn with_callsites( self, callsites: impl IntoIterator<Item = CallSite<E>>, ) -> Self

Adds a callsite to the group.

pub fn with_lookups(self, lookups: impl IntoIterator<Item = IRStmt<E>>) -> Self

Updates the IR of the lookups.

pub fn inject(&mut self, ir: IRStmt<E>)

Injects IR into the body of the group.

pub fn injected_count(&self) -> usize

Returns the number of statements injected into this group.

pub fn do_debug_comments(self, do_it: bool) -> Self

Sets the flag that control the generation of debug comments.

pub fn is_main(&self) -> bool

Returns true if the group is the top-level.

pub fn name(&self) -> &str

Returns the name of the group.

pub fn name_mut(&mut self) -> &mut String

Returns a mutable reference to the group’s name.

pub fn id(&self) -> usize

Returns the id of the group.

pub fn set_id(&mut self, id: usize)

Sets the id of the group.

pub fn input_count(&self) -> usize

Returns the number of inputs.

pub fn output_count(&self) -> usize

Returns the number of outputs.

pub fn key(&self) -> Option<GroupKey>

Returns the key of the group.

pub fn callsites(&self) -> &[CallSite<E>]

Returns a referece to the callsites.

pub fn callsites_mut(&mut self) -> &mut Vec<CallSite<E>>

Returns a mutable referece to the callsites.

pub fn statements(&self) -> impl Iterator<Item = &IRStmt<E>>

Returns an iterator with all the IRStmt in the group.

pub fn try_map<O, Err>( self, f: &mut impl FnMut(E) -> Result<O, Err>, ) -> Result<IRGroup<O>, Err>

Tries to convert the inner expression type to another.

pub fn eq_constraints_mut(&mut self) -> &mut IRStmt<E>

Returns a mutable reference to the copy constraints.