pub struct Meta(/* private fields */);Expand description
Metadata associated with an IR object.
Implementations
Sourceimpl Meta
impl Meta
Sourcepub fn at_gate(
&mut self,
name: impl ToString,
region_name: impl ToString,
region: Option<RegionIndex>,
row: Option<usize>,
)
pub fn at_gate( &mut self, name: impl ToString, region_name: impl ToString, region: Option<RegionIndex>, row: Option<usize>, )
Sets the location at a PLONK gate.
Sourcepub fn at_copy_constraint(&mut self, constraint: CopyConstraint)
pub fn at_copy_constraint(&mut self, constraint: CopyConstraint)
Sets the location at a copy constraint.
Sourcepub fn at_lookup(&mut self, name: impl ToString, idx: usize, row: Option<usize>)
pub fn at_lookup(&mut self, name: impl ToString, idx: usize, row: Option<usize>)
Sets the location at a lookup.
Sourcepub fn at_inject(&mut self, region: RegionIndex, index: Option<usize>)
pub fn at_inject(&mut self, region: RegionIndex, index: Option<usize>)
Sets the location at an injection index.
Sourcepub fn at_group(&mut self, name: impl ToString, key: Option<GroupKey>)
pub fn at_group(&mut self, name: impl ToString, key: Option<GroupKey>)
Sets the group information.
Sourcepub fn complete_with(&mut self, other: Self)
pub fn complete_with(&mut self, other: Self)
Completes the metadata with information from the given instance.
Does not overwrite anything that has already been written.