IRPrinter

Struct IRPrinter 

pub struct IRPrinter<'ir> { /* private fields */ }
Prints a human-friendly representation of the IR meant for debugging.

The structure of the output emitted by the printer is never considered stable and shouldn’t be relied upon as it may change unexpectedly. The purpose of the printer is to be a debugging aid for inspecting the shape of the IR and not a serialization/deserialization format.