IRStmt

Struct IRStmt 

pub struct IRStmt<T>(/* private fields */);
IR for operations that occur in the main circuit.

Implementations

Source

impl<T> IRStmt<T>

pub fn call( callee: impl AsRef<str>, inputs: impl IntoIterator<Item = T>, outputs: impl IntoIterator<Item = Slot>, ) -> Self

Creates a call to another module.

pub fn post_cond(cond: IRBexpr<T>) -> Self

Creates a post condition formula.

pub fn constraint(op: CmpOp, lhs: T, rhs: T) -> Self

Creates a constraint between two expressions.

pub fn eq(lhs: T, rhs: T) -> Self

Creates a constraint with CmpOp::Eq between two expressions.

pub fn lt(lhs: T, rhs: T) -> Self

Creates a constraint with CmpOp::Lt between two expressions.

pub fn le(lhs: T, rhs: T) -> Self

Creates a constraint with CmpOp::Le between two expressions.

pub fn gt(lhs: T, rhs: T) -> Self

Creates a constraint with CmpOp::Gt between two expressions.

pub fn ge(lhs: T, rhs: T) -> Self

Creates a constraint with CmpOp::Ge between two expressions.

pub fn comment(s: impl AsRef<str>) -> Self

Creates a text comment.

pub fn assume_deterministic(f: impl Into<Slot>) -> Self

Indicates that the Slot must be assumed deterministic by the backend.

pub fn assert(cond: IRBexpr<T>) -> Self

Creates an assertion in the circuit.

pub fn seq<I>(stmts: impl IntoIterator<Item = IRStmt<I>>) -> Self
where I: Into<T>,

Creates a statement that is a sequence of other statements.

pub fn empty() -> Self

Creates an empty statement.

pub fn is_empty(&self) -> bool

Returns true if the statement is empty.

pub fn with_comment(self, comment: String) -> Self

Prepends a comment to the statement.

pub fn map<O>(self, f: &mut impl FnMut(T) -> O) -> IRStmt<O>

Transforms the inner expression type into another.

pub fn with<O>(self, other: O) -> IRStmt<(O, T)>
where O: Clone,

Maps the statement’s inner type to a tuple with the passed value.

pub fn with_fn<O>(self, other: impl Fn() -> O) -> IRStmt<(O, T)>

Maps the statement’s inner type to a tuple with the result of the closure.

pub fn into<O>(self) -> IRStmt<O>
where O: From<T> + Evaluate<ExprProperties>,

Transforms the inner expression type using Into::into.

pub fn from<O>(value: IRStmt<O>) -> Self
where O: Into<T>,

Transforms the inner expression type using From::from.

pub fn then(self, other: impl Into<Self>) -> Self

Appends the given statement to the current one.

pub fn map_into<O>(&self, f: &mut impl FnMut(&T) -> O) -> IRStmt<O>

Transforms the inner expression type into another, without moving.

pub fn try_map<O, E>( self, f: &mut impl FnMut(T) -> Result<O, E>, ) -> Result<IRStmt<O>, E>

Tries to transform the inner expression type into another.

pub fn map_inplace(&mut self, f: &mut impl FnMut(&mut T))

Modifies the inner expression type in place.

pub fn try_map_inplace<E>( &mut self, f: &mut impl FnMut(&mut T) -> Result<(), E>, ) -> Result<(), E>

Tries to modify the inner expression type in place.

pub fn map_slot_inplace(&mut self, f: &mut impl FnMut(&mut Slot))

Modifies the inner slots in place.

pub fn try_map_slot_inplace<E>( &mut self, f: &mut impl FnMut(&mut Slot) -> Result<(), E>, ) -> Result<(), E>

Tries to modify the inner slots n place.

pub fn iter(&self) -> IRStmtRefIter<'_, T>

Returns an iterator of references to the statements.

pub fn iter_mut(&mut self) -> IRStmtRefMutIter<'_, T>

Returns an iterator of mutable references to the statements.

pub fn propagate_meta(&mut self)

Propagates the metadata of this statement to the inner statements.