pub struct IRBexpr<A>(/* private fields */);Expand description
Represents boolean expressions over some arithmetic expression type A.
Implementations
Sourceimpl<T> IRBexpr<T>
impl<T> IRBexpr<T>
Sourcepub fn map<O>(self, f: &mut impl FnMut(T) -> O) -> IRBexpr<O>
pub fn map<O>(self, f: &mut impl FnMut(T) -> O) -> IRBexpr<O>
Transforms the inner expression into a different type.
Sourcepub fn map_into<O>(&self, f: &mut impl FnMut(&T) -> O) -> IRBexpr<O>
pub fn map_into<O>(&self, f: &mut impl FnMut(&T) -> O) -> IRBexpr<O>
Transforms the inner expression into a different type without moving the struct.
Sourcepub fn try_map<O, E>(
self,
f: &mut impl FnMut(T) -> Result<O, E>,
) -> Result<IRBexpr<O>, E>
pub fn try_map<O, E>( self, f: &mut impl FnMut(T) -> Result<O, E>, ) -> Result<IRBexpr<O>, E>
Transforms the inner expression into a different type, potentially failing.
Sourcepub fn map_inplace(&mut self, f: &mut impl FnMut(&mut T))
pub fn map_inplace(&mut self, f: &mut impl FnMut(&mut T))
Transforms the inner expression in place instead of returning a new expression.
Sourcepub fn try_map_inplace<E>(
&mut self,
f: &mut impl FnMut(&mut T) -> Result<(), E>,
) -> Result<(), E>
pub fn try_map_inplace<E>( &mut self, f: &mut impl FnMut(&mut T) -> Result<(), E>, ) -> Result<(), E>
Tries to transform the inner expression in place instead of returning a new expression.
Sourcepub fn det(expr: T) -> Self
pub fn det(expr: T) -> Self
Creates a expression that indicates the backend must prove deterministic.
Sourcepub fn and_many(exprs: impl IntoIterator<Item = Self>) -> Self
pub fn and_many(exprs: impl IntoIterator<Item = Self>) -> Self
Creates a logical AND from a sequence of expressions.
Sourcepub fn or_many(exprs: impl IntoIterator<Item = Self>) -> Self
pub fn or_many(exprs: impl IntoIterator<Item = Self>) -> Self
Creates a logical OR from a sequence of expressions.