pub struct IRGroup<E> { /* private fields */ }Expand description
Body of a group.
Implementations
Sourceimpl<E> IRGroup<E>
impl<E> IRGroup<E>
Sourcepub fn with_input_count(self, input_count: usize) -> Self
pub fn with_input_count(self, input_count: usize) -> Self
Updates the input count of the group.
Sourcepub fn with_output_count(self, output_count: usize) -> Self
pub fn with_output_count(self, output_count: usize) -> Self
Updates the output count of the group.
Sourcepub fn with_gates(self, gates: impl IntoIterator<Item = IRStmt<E>>) -> Self
pub fn with_gates(self, gates: impl IntoIterator<Item = IRStmt<E>>) -> Self
Updates the IR of the PLONK gates.
Sourcepub fn with_copy_constraints(
self,
constraints: impl IntoIterator<Item = IRStmt<E>>,
) -> Self
pub fn with_copy_constraints( self, constraints: impl IntoIterator<Item = IRStmt<E>>, ) -> Self
Updates the IR of the copy constraints.
Sourcepub fn with_callsites(
self,
callsites: impl IntoIterator<Item = CallSite<E>>,
) -> Self
pub fn with_callsites( self, callsites: impl IntoIterator<Item = CallSite<E>>, ) -> Self
Adds a callsite to the group.
Sourcepub fn with_lookups(self, lookups: impl IntoIterator<Item = IRStmt<E>>) -> Self
pub fn with_lookups(self, lookups: impl IntoIterator<Item = IRStmt<E>>) -> Self
Updates the IR of the lookups.
Sourcepub fn injected_count(&self) -> usize
pub fn injected_count(&self) -> usize
Returns the number of statements injected into this group.
Sourcepub fn do_debug_comments(self, do_it: bool) -> Self
pub fn do_debug_comments(self, do_it: bool) -> Self
Sets the flag that control the generation of debug comments.
Sourcepub fn input_count(&self) -> usize
pub fn input_count(&self) -> usize
Returns the number of inputs.
Sourcepub fn output_count(&self) -> usize
pub fn output_count(&self) -> usize
Returns the number of outputs.
Sourcepub fn callsites_mut(&mut self) -> &mut Vec<CallSite<E>>
pub fn callsites_mut(&mut self) -> &mut Vec<CallSite<E>>
Returns a mutable referece to the callsites.
Sourcepub fn statements(&self) -> impl Iterator<Item = &IRStmt<E>>
pub fn statements(&self) -> impl Iterator<Item = &IRStmt<E>>
Returns an iterator with all the IRStmt in the group.
Sourcepub fn try_map<O, Err>(
self,
f: &mut impl FnMut(E) -> Result<O, Err>,
) -> Result<IRGroup<O>, Err>
pub fn try_map<O, Err>( self, f: &mut impl FnMut(E) -> Result<O, Err>, ) -> Result<IRGroup<O>, Err>
Tries to convert the inner expression type to another.
Sourcepub fn eq_constraints_mut(&mut self) -> &mut IRStmt<E>
pub fn eq_constraints_mut(&mut self) -> &mut IRStmt<E>
Returns a mutable reference to the copy constraints.