pub struct IRStmt<T>(/* private fields */);Expand description
IR for operations that occur in the main circuit.
Implementations
Sourceimpl<T> IRStmt<T>
impl<T> IRStmt<T>
Sourcepub fn call(
callee: impl AsRef<str>,
inputs: impl IntoIterator<Item = T>,
outputs: impl IntoIterator<Item = Slot>,
) -> Self
pub fn call( callee: impl AsRef<str>, inputs: impl IntoIterator<Item = T>, outputs: impl IntoIterator<Item = Slot>, ) -> Self
Creates a call to another module.
Sourcepub fn constraint(op: CmpOp, lhs: T, rhs: T) -> Self
pub fn constraint(op: CmpOp, lhs: T, rhs: T) -> Self
Creates a constraint between two expressions.
Sourcepub fn assume_deterministic(f: impl Into<Slot>) -> Self
pub fn assume_deterministic(f: impl Into<Slot>) -> Self
Indicates that the Slot must be assumed deterministic by the backend.
Sourcepub fn seq<I>(stmts: impl IntoIterator<Item = IRStmt<I>>) -> Selfwhere
I: Into<T>,
pub fn seq<I>(stmts: impl IntoIterator<Item = IRStmt<I>>) -> Selfwhere
I: Into<T>,
Creates a statement that is a sequence of other statements.
Sourcepub fn with_comment(self, comment: String) -> Self
pub fn with_comment(self, comment: String) -> Self
Prepends a comment to the statement.
Sourcepub fn map<O>(self, f: &mut impl FnMut(T) -> O) -> IRStmt<O>
pub fn map<O>(self, f: &mut impl FnMut(T) -> O) -> IRStmt<O>
Transforms the inner expression type into another.
Sourcepub fn with<O>(self, other: O) -> IRStmt<(O, T)>where
O: Clone,
pub fn with<O>(self, other: O) -> IRStmt<(O, T)>where
O: Clone,
Maps the statement’s inner type to a tuple with the passed value.
Sourcepub fn with_fn<O>(self, other: impl Fn() -> O) -> IRStmt<(O, T)>
pub fn with_fn<O>(self, other: impl Fn() -> O) -> IRStmt<(O, T)>
Maps the statement’s inner type to a tuple with the result of the closure.
Sourcepub fn into<O>(self) -> IRStmt<O>
pub fn into<O>(self) -> IRStmt<O>
Transforms the inner expression type using Into::into.
Sourcepub fn from<O>(value: IRStmt<O>) -> Selfwhere
O: Into<T>,
pub fn from<O>(value: IRStmt<O>) -> Selfwhere
O: Into<T>,
Transforms the inner expression type using From::from.
Sourcepub fn then(self, other: impl Into<Self>) -> Self
pub fn then(self, other: impl Into<Self>) -> Self
Appends the given statement to the current one.
Sourcepub fn map_into<O>(&self, f: &mut impl FnMut(&T) -> O) -> IRStmt<O>
pub fn map_into<O>(&self, f: &mut impl FnMut(&T) -> O) -> IRStmt<O>
Transforms the inner expression type into another, without moving.
Sourcepub fn try_map<O, E>(
self,
f: &mut impl FnMut(T) -> Result<O, E>,
) -> Result<IRStmt<O>, E>
pub fn try_map<O, E>( self, f: &mut impl FnMut(T) -> Result<O, E>, ) -> Result<IRStmt<O>, E>
Tries to transform the inner expression type into another.
Sourcepub fn map_inplace(&mut self, f: &mut impl FnMut(&mut T))
pub fn map_inplace(&mut self, f: &mut impl FnMut(&mut T))
Modifies the inner expression type in place.
Sourcepub fn try_map_inplace<E>(
&mut self,
f: &mut impl FnMut(&mut T) -> Result<(), E>,
) -> Result<(), E>
pub fn try_map_inplace<E>( &mut self, f: &mut impl FnMut(&mut T) -> Result<(), E>, ) -> Result<(), E>
Tries to modify the inner expression type in place.
Sourcepub fn map_slot_inplace(&mut self, f: &mut impl FnMut(&mut Slot))
pub fn map_slot_inplace(&mut self, f: &mut impl FnMut(&mut Slot))
Modifies the inner slots in place.
Sourcepub fn try_map_slot_inplace<E>(
&mut self,
f: &mut impl FnMut(&mut Slot) -> Result<(), E>,
) -> Result<(), E>
pub fn try_map_slot_inplace<E>( &mut self, f: &mut impl FnMut(&mut Slot) -> Result<(), E>, ) -> Result<(), E>
Tries to modify the inner slots n place.
Sourcepub fn iter(&self) -> IRStmtRefIter<'_, T> ⓘ
pub fn iter(&self) -> IRStmtRefIter<'_, T> ⓘ
Returns an iterator of references to the statements.
Sourcepub fn iter_mut(&mut self) -> IRStmtRefMutIter<'_, T> ⓘ
pub fn iter_mut(&mut self) -> IRStmtRefMutIter<'_, T> ⓘ
Returns an iterator of mutable references to the statements.
Sourcepub fn propagate_meta(&mut self)
pub fn propagate_meta(&mut self)
Propagates the metadata of this statement to the inner statements.